@@ -8,10 +8,9 @@
 
 from dataclasses import dataclass
 
+from detector_connector import DetectorSettings
 
-@dataclass
-class ObstructionSettings:
-    rtsp_url: str
+
+@dataclass(kw_only=True, frozen=True)
+class ObstructionSettings(DetectorSettings):
     similarity_threshold: float
-    created_at: float | None = None
-    updated_at: float | None = None
